@@ -9,15 +9,16 @@
 using namespace icu;
 
 void init_rbbi(py::module &m) {
-  // BreakIterator
-  py::class_<BreakIterator> bi(m, "BreakIterator");
+  // icu::BreakIterator
+  py::class_<BreakIterator, UObject> bi(m, "BreakIterator");
 
   py::enum_<decltype(BreakIterator::DONE)>(bi, "BreakIterator", py::arithmetic())
       .value("DONE", BreakIterator::DONE)
       .export_values();
 
   bi.def("__copy__", &BreakIterator::clone)
-      .def("__deepcopy__", [](const BreakIterator &self, py::dict) { return self.clone(); })
+      .def(
+          "__deepcopy__", [](const BreakIterator &self, py::dict) { return self.clone(); }, py::arg("memo"))
       .def("__iter__",
            [](BreakIterator &self) -> BreakIterator & {
              self.first();
@@ -39,69 +40,158 @@ void init_rbbi(py::module &m) {
         return result;
       });
   bi.def_static(
-      "create_character_instance",
-      [](const Locale &where) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto it = BreakIterator::createCharacterInstance(where, error_code);
-        if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
-        }
-        return it;
-      },
-      py::arg("where"));
+        "create_character_instance",
+        [](const Locale &where) {
+          UErrorCode error_code = U_ZERO_ERROR;
+          auto it = BreakIterator::createCharacterInstance(where, error_code);
+          if (U_FAILURE(error_code)) {
+            throw ICUException(error_code);
+          }
+          return it;
+        },
+        py::arg("where"))
+      .def_static(
+          // const char *where -> const Locale &where
+          "create_character_instance",
+          [](const char *where) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto it = BreakIterator::createCharacterInstance(where, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return it;
+          },
+          py::arg("where"));
   bi.def_static(
-      "create_line_instance",
-      [](const Locale &where) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto it = BreakIterator::createLineInstance(where, error_code);
-        if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
-        }
-        return it;
-      },
-      py::arg("where"));
+        "create_line_instance",
+        [](const Locale &where) {
+          UErrorCode error_code = U_ZERO_ERROR;
+          auto it = BreakIterator::createLineInstance(where, error_code);
+          if (U_FAILURE(error_code)) {
+            throw ICUException(error_code);
+          }
+          return it;
+        },
+        py::arg("where"))
+      .def_static(
+          // const char *where -> const Locale &where
+          "create_line_instance",
+          [](const char *where) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto it = BreakIterator::createLineInstance(where, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return it;
+          },
+          py::arg("where"));
   bi.def_static(
-      "create_sentence_instance",
-      [](const Locale &where) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto it = BreakIterator::createSentenceInstance(where, error_code);
-        if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
-        }
-        return it;
-      },
-      py::arg("where"));
+        "create_sentence_instance",
+        [](const Locale &where) {
+          UErrorCode error_code = U_ZERO_ERROR;
+          auto it = BreakIterator::createSentenceInstance(where, error_code);
+          if (U_FAILURE(error_code)) {
+            throw ICUException(error_code);
+          }
+          return it;
+        },
+        py::arg("where"))
+      .def_static(
+          // const char *where -> const Locale &where
+          "create_sentence_instance",
+          [](const char *where) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto it = BreakIterator::createSentenceInstance(where, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return it;
+          },
+          py::arg("where"));
 #ifndef U_HIDE_DEPRECATED_API
   bi.def_static(
-      "create_title_instance",
-      [](const Locale &where) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto it = BreakIterator::createTitleInstance(where, error_code);
-        if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
-        }
-        return it;
-      },
-      py::arg("where"));
+        "create_title_instance",
+        [](const Locale &where) {
+          UErrorCode error_code = U_ZERO_ERROR;
+          auto it = BreakIterator::createTitleInstance(where, error_code);
+          if (U_FAILURE(error_code)) {
+            throw ICUException(error_code);
+          }
+          return it;
+        },
+        py::arg("where"))
+      .def_static(
+          // const char *where -> const Locale &where
+          "create_title_instance",
+          [](const char *where) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto it = BreakIterator::createTitleInstance(where, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return it;
+          },
+          py::arg("where"));
 #endif // U_HIDE_DEPRECATED_API
   bi.def_static(
-      "create_word_instance",
-      [](const Locale &where) {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto it = BreakIterator::createWordInstance(where, error_code);
-        if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
-        }
-        return it;
-      },
-      py::arg("where"));
+        "create_word_instance",
+        [](const Locale &where) {
+          UErrorCode error_code = U_ZERO_ERROR;
+          auto it = BreakIterator::createWordInstance(where, error_code);
+          if (U_FAILURE(error_code)) {
+            throw ICUException(error_code);
+          }
+          return it;
+        },
+        py::arg("where"))
+      .def_static(
+          // const char *where -> const Locale &where
+          "create_word_instance",
+          [](const char *where) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto it = BreakIterator::createWordInstance(where, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return it;
+          },
+          py::arg("where"));
   bi.def_static("get_available_locales", py::overload_cast<>(&BreakIterator::getAvailableLocales));
   bi.def_static("get_display_name",
                 py::overload_cast<const Locale &, const Locale &, UnicodeString &>(&BreakIterator::getDisplayName),
                 py::arg("object_locale"), py::arg("display_locale"), py::arg("name"))
+      .def_static(
+          // const char *object_locale -> const Locale &object_locale
+          "get_display_name",
+          [](const char *object_locale, const Locale &display_locale, UnicodeString &name) -> UnicodeString & {
+            return BreakIterator::getDisplayName(object_locale, display_locale, name);
+          },
+          py::arg("object_locale"), py::arg("display_locale"), py::arg("name"))
+      .def_static(
+          // const char *display_locale -> const Locale &display_locale
+          "get_display_name",
+          [](const Locale &object_locale, const char *display_locale, UnicodeString &name) -> UnicodeString & {
+            return BreakIterator::getDisplayName(object_locale, display_locale, name);
+          },
+          py::arg("object_locale"), py::arg("display_locale"), py::arg("name"))
+      .def_static(
+          // const char *object_locale -> const Locale &object_locale
+          // const char *display_locale -> const Locale &display_locale
+          "get_display_name",
+          [](const char *object_locale, const char *display_locale, UnicodeString &name) -> UnicodeString & {
+            return BreakIterator::getDisplayName(object_locale, display_locale, name);
+          },
+          py::arg("object_locale"), py::arg("display_locale"), py::arg("name"))
       .def_static("get_display_name",
                   py::overload_cast<const Locale &, UnicodeString &>(&BreakIterator::getDisplayName),
-                  py::arg("object_locale"), py::arg("name"));
+                  py::arg("object_locale"), py::arg("name"))
+      .def_static(
+          // const char *object_locale -> const Locale &object_locale
+          "get_display_name",
+          [](const char *object_locale, UnicodeString &name) -> UnicodeString & {
+            return BreakIterator::getDisplayName(object_locale, name);
+          },
+          py::arg("object_locale"), py::arg("name"));
   bi.def(
       "get_locale",
       [](const BreakIterator &self, ULocDataLocaleType type) {
@@ -130,29 +220,46 @@ void init_rbbi(py::module &m) {
   // UBreakIteratorType kind,	UErrorCode &status)".
   // TODO: Implement "static UBool unregister(URegistryKey key, UErrorCode &status)".
 
-  // RuleBasedBreakIterator
+  // icu::RuleBasedBreakIterator
   py::class_<RuleBasedBreakIterator, BreakIterator> rbbi(m, "RuleBasedBreakIterator");
-  rbbi.def(py::init<const RuleBasedBreakIterator &>(), py::arg("that"))
-      .def(py::init([](const UnicodeString &rules, UParseError &parse_error) {
-             UErrorCode error_code = U_ZERO_ERROR;
-             auto result = std::make_unique<RuleBasedBreakIterator>(rules, parse_error, error_code);
-             if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
-             }
-             return result;
-           }),
-           py::arg("rules"), py::arg("parse_error"))
-      .def(py::init([](const std::vector<uint8_t> &compiled_rules, uint32_t rule_length) {
-             UErrorCode error_code = U_ZERO_ERROR;
-             auto result = std::make_unique<RuleBasedBreakIterator>(compiled_rules.data(), rule_length, error_code);
-             if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
-             }
-             return result;
-           }),
-           py::arg("compiled_rules"), py::arg("rule_length"))
-      .def(py::self != py::self)
-      .def(py::self == py::self);
+  rbbi.def(
+          // [2] RuleBasedBreakIterator::RuleBasedBreakIterator
+          py::init<const RuleBasedBreakIterator &>(), py::arg("that"))
+      .def(
+          // [3] RuleBasedBreakIterator::RuleBasedBreakIterator
+          py::init([](const UnicodeString &rules, UParseError &parse_error) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<RuleBasedBreakIterator>(rules, parse_error, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("rules"), py::arg("parse_error"))
+      .def(
+          // const char16_t *rules -> const UnicodeString &rules
+          py::init([](const char16_t *rules, UParseError &parse_error) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<RuleBasedBreakIterator>(rules, parse_error, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("rules"), py::arg("parse_error"))
+      .def(
+          // [4] RuleBasedBreakIterator::RuleBasedBreakIterator
+          py::init([](const std::vector<uint8_t> &compiled_rules, uint32_t rule_length) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<RuleBasedBreakIterator>(compiled_rules.data(), rule_length, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("compiled_rules"), py::arg("rule_length"))
+      .def(py::self != py::self, py::arg("other"))
+      .def(py::self == py::self, py::arg("other"));
   rbbi.def(
       "adopt_text",
       [](RuleBasedBreakIterator &self, CharacterIterator *it) { self.adoptText(it ? it->clone() : NULL); },
