@@ -13,43 +13,78 @@ using namespace icu;
 
 void init_regex(py::module &m) {
   // icu::RegexMatcher
-  py::class_<RegexMatcher> rm(m, "RegexMatcher");
-  rm.def(py::init([](const UnicodeString &regexp, uint32_t flags) {
-           UErrorCode error_code = U_ZERO_ERROR;
-           auto result = std::make_unique<RegexMatcher>(regexp, flags, error_code);
-           if (U_FAILURE(error_code)) {
-             throw ICUException(error_code);
-           }
-           return result;
-         }),
-         py::arg("regexp"), py::arg("flags"))
-      .def(py::init([](_UTextPtr &regexp, uint32_t flags) {
-             UErrorCode error_code = U_ZERO_ERROR;
-             auto result = std::make_unique<RegexMatcher>(regexp, flags, error_code);
-             if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
-             }
-             return result;
-           }),
-           py::arg("regexp"), py::arg("flags"))
-      .def(py::init([](const UnicodeString &regexp, const UnicodeString &input, uint32_t flags) {
-             UErrorCode error_code = U_ZERO_ERROR;
-             auto result = std::make_unique<RegexMatcher>(regexp, input, flags, error_code);
-             if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
-             }
-             return result;
-           }),
-           py::arg("regexp"), py::arg("input_"), py::arg("flags"))
-      .def(py::init([](_UTextPtr &regexp, _UTextPtr &input, uint32_t flags) {
-             UErrorCode error_code = U_ZERO_ERROR;
-             auto result = std::make_unique<RegexMatcher>(regexp, input, flags, error_code);
-             if (U_FAILURE(error_code)) {
-               throw ICUException(error_code);
-             }
-             return result;
-           }),
-           py::arg("regexp"), py::arg("input_"), py::arg("flags"));
+  py::class_<RegexMatcher, UObject> rm(m, "RegexMatcher");
+
+  // icu::RegexPattern
+  py::class_<RegexPattern, UObject> rp(m, "RegexPattern");
+
+  // icu::RegexMatcher
+  rm.def(
+        // [1] RegexMatcher::RegexMatcher
+        py::init([](const UnicodeString &regexp, uint32_t flags) {
+          UErrorCode error_code = U_ZERO_ERROR;
+          auto result = std::make_unique<RegexMatcher>(regexp, flags, error_code);
+          if (U_FAILURE(error_code)) {
+            throw ICUException(error_code);
+          }
+          return result;
+        }),
+        py::arg("regexp"), py::arg("flags"))
+      .def(
+          // const char16_t *regexp -> const UnicodeString &regexp
+          py::init([](const char16_t *regexp, uint32_t flags) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<RegexMatcher>(regexp, flags, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("regexp"), py::arg("flags"))
+      .def(
+          // [2] RegexMatcher::RegexMatcher
+          py::init([](_UTextPtr &regexp, uint32_t flags) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<RegexMatcher>(regexp, flags, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("regexp"), py::arg("flags"))
+      .def(
+          // [3] RegexMatcher::RegexMatcher
+          py::init([](const UnicodeString &regexp, const UnicodeString &input, uint32_t flags) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<RegexMatcher>(regexp, input, flags, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("regexp"), py::arg("input_"), py::arg("flags"))
+      .def(
+          // const char16_t *regexp -> const UnicodeString &regexp
+          py::init([](const char16_t *regexp, const UnicodeString &input, uint32_t flags) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<RegexMatcher>(regexp, input, flags, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("regexp"), py::arg("input_"), py::arg("flags"))
+      .def(
+          // [4] RegexMatcher::RegexMatcher
+          py::init([](_UTextPtr &regexp, _UTextPtr &input, uint32_t flags) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = std::make_unique<RegexMatcher>(regexp, input, flags, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          }),
+          py::arg("regexp"), py::arg("input_"), py::arg("flags"));
   rm.def(
         "append_replacement",
         [](RegexMatcher &self, UnicodeString &dest, const UnicodeString &replacement) -> RegexMatcher & {
@@ -61,6 +96,18 @@ void init_regex(py::module &m) {
           return result;
         },
         py::arg("dest"), py::arg("replacement"))
+      .def(
+          // const char16_t *replacement -> const UnicodeString &replacement
+          "append_replacement",
+          [](RegexMatcher &self, UnicodeString &dest, const char16_t *replacement) -> RegexMatcher & {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto &result = self.appendReplacement(dest, replacement, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("dest"), py::arg("replacement"))
       .def(
           "append_replacement",
           [](RegexMatcher &self, _UTextPtr &dest, _UTextPtr &replacement) -> RegexMatcher & {
@@ -325,6 +372,18 @@ void init_regex(py::module &m) {
           return result;
         },
         py::arg("replacement"))
+      .def(
+          // const char16_t *replacement -> const UnicodeString &replacement
+          "replace_all",
+          [](RegexMatcher &self, const char16_t *replacement) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.replaceAll(replacement, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("replacement"))
       .def(
           "replace_all",
           [](RegexMatcher &self, _UTextPtr &replacement, std::optional<_UTextPtr> &dest) {
@@ -347,6 +406,18 @@ void init_regex(py::module &m) {
           return result;
         },
         py::arg("replacement"))
+      .def(
+          // const char16_t *replacement -> const UnicodeString &replacement
+          "replace_first",
+          [](RegexMatcher &self, const char16_t *replacement) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.replaceFirst(replacement, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("replacement"))
       .def(
           "replace_first",
           [](RegexMatcher &self, _UTextPtr &replacement, std::optional<_UTextPtr> &dest) {
@@ -505,14 +576,13 @@ void init_regex(py::module &m) {
   rm.def("use_transparent_bounds", &RegexMatcher::useTransparentBounds, py::arg("b"));
 
   // icu::RegexPattern
-  py::class_<RegexPattern> rp(m, "RegexPattern");
   rp.def(py::init<>())
       .def(py::init<const RegexPattern &>(), py::arg("source"))
-      .def(py::self != py::self)
-      .def(py::self == py::self);
-  rp.def("__copy__", &RegexPattern::clone).def("__deepcopy__", [](const RegexPattern &self, py::dict) {
-    return self.clone();
-  });
+      .def(py::self != py::self, py::arg("other"))
+      .def(py::self == py::self, py::arg("other"));
+  rp.def("__copy__", &RegexPattern::clone)
+      .def(
+          "__deepcopy__", [](const RegexPattern &self, py::dict) { return self.clone(); }, py::arg("memo"));
   rp.def("clone", &RegexPattern::clone);
   rp.def_static(
         "compile",
@@ -525,6 +595,18 @@ void init_regex(py::module &m) {
           return result;
         },
         py::arg("regex"), py::arg("flags"))
+      .def_static(
+          // const char16_t *regex -> const UnicodeString &regex
+          "compile",
+          [](const char16_t *regex, uint32_t flags) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = RegexPattern::compile(regex, flags, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("regex"), py::arg("flags"))
       .def_static(
           "compile",
           [](const UnicodeString &regex, uint32_t flags, UParseError &pe) {
@@ -536,6 +618,18 @@ void init_regex(py::module &m) {
             return result;
           },
           py::arg("regex"), py::arg("flags"), py::arg("pe"))
+      .def_static(
+          // const char16_t *regex -> const UnicodeString &regex
+          "compile",
+          [](const char16_t *regex, uint32_t flags, UParseError &pe) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = RegexPattern::compile(regex, flags, pe, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("regex"), py::arg("flags"), py::arg("pe"))
       .def_static(
           "compile",
           [](const UnicodeString &regex, UParseError &pe) {
@@ -547,6 +641,18 @@ void init_regex(py::module &m) {
             return result;
           },
           py::arg("regex"), py::arg("pe"))
+      .def_static(
+          // const char16_t *regex -> const UnicodeString &regex
+          "compile",
+          [](const char16_t *regex, UParseError &pe) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = RegexPattern::compile(regex, pe, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("regex"), py::arg("pe"))
       .def_static(
           "compile",
           [](_UTextPtr &regex, uint32_t flags) {
@@ -603,6 +709,18 @@ void init_regex(py::module &m) {
             }
             return result;
           },
+          py::arg("group_name"))
+      .def(
+          // const char16_t *group_name -> const UnicodeString &group_name
+          "group_number_from_name",
+          [](const RegexPattern &self, const char16_t *group_name) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.groupNumberFromName(group_name, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
           py::arg("group_name"));
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 55)
   rp.def(
@@ -635,6 +753,18 @@ void init_regex(py::module &m) {
           return result;
         },
         py::arg("regex"), py::arg("input_"), py::arg("pe"))
+      .def_static(
+          // const char16_t *regex -> const UnicodeString &regex
+          "matches",
+          [](const char16_t *regex, const UnicodeString &input, UParseError &pe) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = RegexPattern::matches(regex, input, pe, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("regex"), py::arg("input_"), py::arg("pe"))
       .def_static(
           "matches",
           [](_UTextPtr &regex, _UTextPtr &input, UParseError &pe) {
