@@ -6,14 +6,14 @@
 using namespace icu;
 
 void init_schriter(py::module &m) {
-  // ForwardCharacterIterator
-  py::class_<ForwardCharacterIterator> fci(m, "ForwardCharacterIterator");
+  // icu::ForwardCharacterIterator
+  py::class_<ForwardCharacterIterator, UObject> fci(m, "ForwardCharacterIterator");
 
   py::enum_<decltype(ForwardCharacterIterator::DONE)>(fci, "ForwardCharacterIterator", py::arithmetic())
       .value("DONE", ForwardCharacterIterator::DONE)
       .export_values();
 
-  // CharacterIterator
+  // icu::CharacterIterator
   py::class_<CharacterIterator, ForwardCharacterIterator> ci(m, "CharacterIterator");
 
   py::enum_<CharacterIterator::EOrigin>(ci, "EOrigin", py::arithmetic())
@@ -23,7 +23,8 @@ void init_schriter(py::module &m) {
       .export_values();
 
   ci.def("__copy__", &CharacterIterator::clone)
-      .def("__deepcopy__", [](const CharacterIterator &self, py::dict) { return self.clone(); })
+      .def(
+          "__deepcopy__", [](const CharacterIterator &self, py::dict) { return self.clone(); }, py::arg("memo"))
       .def("__len__", &CharacterIterator::getLength)
       .def("__str__", [](CharacterIterator &self) {
         UnicodeString dest;
@@ -41,7 +42,7 @@ void init_schriter(py::module &m) {
   ci.def("set_to_start", &CharacterIterator::setToStart);
   ci.def("start_index", &CharacterIterator::startIndex);
 
-  // UCharCharacterIterator
+  // icu::UCharCharacterIterator
   py::class_<UCharCharacterIterator, CharacterIterator> uci(m, "UCharCharacterIterator");
   /*
   uci.def(py::init<ConstChar16Ptr, int32_t>(), py::arg("text_ptr"), py::arg("length"))
@@ -51,7 +52,10 @@ void init_schriter(py::module &m) {
       .def(py::init<const UCharCharacterIterator &>(), py::arg("that"));
   uci.def("set_text", &UCharCharacterIterator::setText, py::arg("new_text"), py::arg("new_text_length"));
   */
-  uci.def(py::self != py::self).def(py::self == py::self);
+  uci.def(py::self != py::self, py::arg("other")).def(py::self == py::self, py::arg("other"));
+  uci.def("__copy__", &UCharCharacterIterator::clone)
+      .def(
+          "__deepcopy__", [](const UCharCharacterIterator &self, py::dict) { return self.clone(); }, py::arg("memo"));
   uci.def("clone", &UCharCharacterIterator::clone);
   uci.def("current", [](const UCharCharacterIterator &self) -> uint16_t { return self.current(); });
   uci.def("current32", &UCharCharacterIterator::current32);
@@ -76,20 +80,23 @@ void init_schriter(py::module &m) {
       py::arg("position"));
   uci.def("set_index32", &UCharCharacterIterator::setIndex32, py::arg("position"));
 
-  // StringCharacterIterator
+  // icu::StringCharacterIterator
   py::class_<StringCharacterIterator, UCharCharacterIterator> sci(m, "StringCharacterIterator");
   sci.def(py::init<const UnicodeString &>(), py::arg("text_str"))
       .def(py::init<const UnicodeString &, int32_t>(), py::arg("text_str"), py::arg("text_pos"))
       .def(py::init<const UnicodeString &, int32_t, int32_t, int32_t>(), py::arg("text_str"), py::arg("text_begin"),
            py::arg("text_end"), py::arg("text_pos"))
       .def(py::init<const StringCharacterIterator &>(), py::arg("that"))
-      .def(py::self != py::self)
-      .def(py::self == py::self);
-  sci.def("__iter__",
-          [](StringCharacterIterator &self) -> StringCharacterIterator & {
-            self.first32();
-            return self;
-          })
+      .def(py::self != py::self, py::arg("other"))
+      .def(py::self == py::self, py::arg("other"));
+  sci.def("__copy__", &StringCharacterIterator::clone)
+      .def(
+          "__deepcopy__", [](const StringCharacterIterator &self, py::dict) { return self.clone(); }, py::arg("memo"))
+      .def("__iter__",
+           [](StringCharacterIterator &self) -> StringCharacterIterator & {
+             self.first32();
+             return self;
+           })
       .def("__next__",
            [](StringCharacterIterator &self) {
              if (self.getIndex() == self.endIndex()) {
