@@ -10,7 +10,7 @@ using namespace icu;
 
 void init_tblcoll(py::module &m) {
   // icu::Collator
-  py::class_<Collator> coll(m, "Collator");
+  py::class_<Collator, UObject> coll(m, "Collator");
 
   py::enum_<Collator::ECollationStrength>(coll, "ECollationStrength", py::arithmetic())
       .value("PRIMARY", Collator::PRIMARY)
@@ -28,9 +28,9 @@ void init_tblcoll(py::module &m) {
       .export_values();
 #endif // U_FORCE_HIDE_DEPRECATED_API
 
-  coll.def("__copy__", &Collator::clone).def("__deepcopy__", [](const Collator &self, py::dict) {
-    return self.clone();
-  });
+  coll.def("__copy__", &Collator::clone)
+      .def(
+          "__deepcopy__", [](const Collator &self, py::dict) { return self.clone(); }, py::arg("memo"));
   coll.def_static(
           "create_instance",
           [](const Locale &loc) {
@@ -50,7 +50,29 @@ void init_tblcoll(py::module &m) {
         }
         return result;
       });
-  coll.def("equals", &Collator::equals, py::arg("source"), py::arg("target"));
+  coll.def("equals", &Collator::equals, py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          "equals",
+          [](const Collator &self, const char16_t *source, const UnicodeString &target) {
+            return self.equals(source, target);
+          },
+          py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *target -> const UnicodeString &target
+          "equals",
+          [](const Collator &self, const UnicodeString &source, const char16_t *target) {
+            return self.equals(source, target);
+          },
+          py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          // const char16_t *target -> const UnicodeString &target
+          "equals",
+          [](const Collator &self, const char16_t *source, const char16_t *target) {
+            return self.equals(source, target);
+          },
+          py::arg("source"), py::arg("target"));
   coll.def_static("get_available_locales", py::overload_cast<>(&Collator::getAvailableLocales));
   coll.def_static(
       "get_bound",
@@ -129,8 +151,52 @@ void init_tblcoll(py::module &m) {
         return result;
       },
       py::arg("keyword"), py::arg("locale"), py::arg("commonly_used"));
-  coll.def("greater", &Collator::greater, py::arg("source"), py::arg("target"));
-  coll.def("greater_or_equal", &Collator::greaterOrEqual, py::arg("source"), py::arg("target"));
+  coll.def("greater", &Collator::greater, py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          "greater",
+          [](const Collator &self, const char16_t *source, const UnicodeString &target) {
+            return self.greater(source, target);
+          },
+          py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *target -> const UnicodeString &target
+          "greater",
+          [](const Collator &self, const UnicodeString &source, const char16_t *target) {
+            return self.greater(source, target);
+          },
+          py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          // const char16_t *target -> const UnicodeString &target
+          "greater",
+          [](const Collator &self, const char16_t *source, const char16_t *target) {
+            return self.greater(source, target);
+          },
+          py::arg("source"), py::arg("target"));
+  coll.def("greater_or_equal", &Collator::greaterOrEqual, py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          "greater_or_equal",
+          [](const Collator &self, const char16_t *source, const UnicodeString &target) {
+            return self.greaterOrEqual(source, target);
+          },
+          py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *target -> const UnicodeString &target
+          "greater_or_equal",
+          [](const Collator &self, const UnicodeString &source, const char16_t *target) {
+            return self.greaterOrEqual(source, target);
+          },
+          py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          // const char16_t *target -> const UnicodeString &target
+          "greater_or_equal",
+          [](const Collator &self, const char16_t *source, const char16_t *target) {
+            return self.greaterOrEqual(source, target);
+          },
+          py::arg("source"), py::arg("target"));
   // TODO: Implement "static URegistryKey icu::Collator::registerFactory(CollatorFactory *toAdopt, UErrorCode &status)".
   // TODO: Implement "static URegistryKey icu::Collator::registerInstance(Collator *toAdopt, const Locale &locale,
   // UErrorCode &status)".
@@ -138,7 +204,6 @@ void init_tblcoll(py::module &m) {
 
   // icu::RuleBasedCollator
   py::class_<RuleBasedCollator, Collator> rbc(m, "RuleBasedCollator");
-  rbc.def(py::self == py::self);
   rbc.def(py::init([](const UnicodeString &rules) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto result = std::make_unique<RuleBasedCollator>(rules, error_code);
@@ -191,7 +256,11 @@ void init_tblcoll(py::module &m) {
            }),
            py::arg("bin"), py::arg("length"), py::arg("base"));
       */
-      ;
+      .def(py::self != py::self, py::arg("other"))
+      .def(py::self == py::self, py::arg("other"));
+  rbc.def("__copy__", &RuleBasedCollator::clone)
+      .def(
+          "__deepcopy__", [](const RuleBasedCollator &self, py::dict) { return self.clone(); }, py::arg("memo"));
   rbc.def("clone", &RuleBasedCollator::clone);
   rbc.def("clone_binary", [](const RuleBasedCollator &self) {
     UErrorCode error_code = U_ZERO_ERROR;
@@ -227,6 +296,43 @@ void init_tblcoll(py::module &m) {
             return result;
           },
           py::arg("source"), py::arg("target"), py::arg("length"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          "compare",
+          [](const RuleBasedCollator &self, const char16_t *source, const UnicodeString &target, int32_t length) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.compare(source, target, length, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("source"), py::arg("target"), py::arg("length"))
+      .def(
+          // const char16_t *target -> const UnicodeString &target
+          "compare",
+          [](const RuleBasedCollator &self, const UnicodeString &source, const char16_t *target, int32_t length) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.compare(source, target, length, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("source"), py::arg("target"), py::arg("length"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          // const char16_t *target -> const UnicodeString &target
+          "compare",
+          [](const RuleBasedCollator &self, const char16_t *source, const char16_t *target, int32_t length) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.compare(source, target, length, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("source"), py::arg("target"), py::arg("length"))
       .def(
           "compare",
           [](const RuleBasedCollator &self, const UnicodeString &source, const UnicodeString &target) {
@@ -238,6 +344,43 @@ void init_tblcoll(py::module &m) {
             return result;
           },
           py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          "compare",
+          [](const RuleBasedCollator &self, const char16_t *source, const UnicodeString &target) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.compare(source, target, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *target -> const UnicodeString &target
+          "compare",
+          [](const RuleBasedCollator &self, const UnicodeString &source, const char16_t *target) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.compare(source, target, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("source"), py::arg("target"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          // const char16_t *target -> const UnicodeString &target
+          "compare",
+          [](const RuleBasedCollator &self, const char16_t *source, const char16_t *target) {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto result = self.compare(source, target, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("source"), py::arg("target"))
       // FIXME: Implement uiter C API.
       /*
       .def(
@@ -292,6 +435,18 @@ void init_tblcoll(py::module &m) {
             }
             return result;
           },
+          py::arg("source"), py::arg("key"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          "get_collation_key",
+          [](const RuleBasedCollator &self, const char16_t *source, CollationKey &key) -> CollationKey & {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto &result = self.getCollationKey(source, key, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
           py::arg("source"), py::arg("key"));
 #if (U_ICU_VERSION_MAJOR_NUM >= 53)
   rbc.def("get_max_variable", &RuleBasedCollator::getMaxVariable);
@@ -327,6 +482,16 @@ void init_tblcoll(py::module &m) {
             self.getSortKey(source, result.data(), result_length);
             return result;
           },
+          py::arg("source"))
+      .def(
+          // const char16_t *source -> const UnicodeString &source
+          "get_sort_key",
+          [](const RuleBasedCollator &self, const char16_t *source) {
+            const auto result_length = self.getSortKey(source, NULL, 0);
+            std::vector<uint8_t> result(result_length);
+            self.getSortKey(source, result.data(), result_length);
+            return result;
+          },
           py::arg("source"));
   rbc.def("get_tailored_set", [](const RuleBasedCollator &self) {
     UErrorCode error_code = U_ZERO_ERROR;
