@@ -13,22 +13,22 @@
 using namespace icu;
 
 void init_uniset(py::module &m) {
-  // UMatchDegree
+  // icu::UMatchDegree
   py::enum_<UMatchDegree>(m, "UMatchDegree", py::arithmetic())
       .value("U_MISMATCH", U_MISMATCH)
       .value("U_PARTIAL_MATCH", U_PARTIAL_MATCH)
       .value("U_MATCH", U_MATCH);
 
-  // UnicodeFunctor
-  py::class_<UnicodeFunctor>(m, "UnicodeFunctor");
+  // icu::UnicodeFunctor
+  py::class_<UnicodeFunctor, UObject>(m, "UnicodeFunctor");
 
-  // UnicodeMatcher
+  // icu::UnicodeMatcher
   py::class_<UnicodeMatcher>(m, "UnicodeMatcher");
 
-  // UnicodeFilter
+  // icu::UnicodeFilter
   py::class_<UnicodeFilter, UnicodeFunctor, UnicodeMatcher>(m, "UnicodeFilter");
 
-  // UnicodeSet
+  // icu::UnicodeSet
   py::class_<UnicodeSet, UnicodeFilter> us(m, "UnicodeSet");
 
   py::enum_<decltype(UnicodeSet::MIN_VALUE)>(us, "UnicodeSet", py::arithmetic())
@@ -58,21 +58,24 @@ void init_uniset(py::module &m) {
            }),
            py::arg("pattern"), py::arg("pos"), py::arg("options"), py::arg("symbols"))
       .def(py::init<const UnicodeSet &>(), py::arg("o"))
-      .def(py::self != py::self)
-      .def(py::self == py::self);
+      .def(py::self != py::self, py::arg("other"))
+      .def(py::self == py::self, py::arg("other"));
   us.def(
         "__contains__", [](const UnicodeSet &self, const UnicodeString &item) { return self.contains(item); },
         py::arg("item"))
+      .def(
+          "__contains__", [](const UnicodeSet &self, char16_t *item) { return self.contains(item); }, py::arg("item"))
       .def(
           "__contains__", [](const UnicodeSet &self, UChar32 item) { return self.contains(item); }, py::arg("item"))
       .def("__copy__", &UnicodeSet::clone)
-      .def("__deepcopy__", [](const UnicodeSet &self, py::dict) { return self.clone(); })
       .def(
-          "__eq__", [](const UnicodeSet &self, _ConstUSetPtr &item) { return self.toUSet() == item; },
-          py::is_operator(), py::arg("item"))
+          "__deepcopy__", [](const UnicodeSet &self, py::dict) { return self.clone(); }, py::arg("memo"))
       .def(
-          "__eq__", [](const UnicodeSet &self, _USetPtr &item) { return self.toUSet() == item; }, py::is_operator(),
-          py::arg("item"))
+          "__eq__", [](const UnicodeSet &self, _ConstUSetPtr &other) { return self.toUSet() == other; },
+          py::is_operator(), py::arg("other"))
+      .def(
+          "__eq__", [](const UnicodeSet &self, _USetPtr &other) { return self.toUSet() == other; }, py::is_operator(),
+          py::arg("other"))
       .def(
           "__getitem__",
           [](const UnicodeSet &self, int32_t index) {
@@ -111,10 +114,16 @@ void init_uniset(py::module &m) {
         return ss.str();
       });
   us.def("add", py::overload_cast<const UnicodeString &>(&UnicodeSet::add), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "add", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.add(s); }, py::arg("s"))
       .def("add", py::overload_cast<UChar32>(&UnicodeSet::add), py::arg("c"))
       .def("add", py::overload_cast<UChar32, UChar32>(&UnicodeSet::add), py::arg("start"), py::arg("end"));
   us.def("add_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::addAll), py::arg("c"))
-      .def("add_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::addAll), py::arg("s"));
+      .def("add_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::addAll), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "add_all", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.addAll(s); }, py::arg("s"));
   us.def("add_match_set_to", &UnicodeSet::addMatchSetTo, py::arg("to_union_to"));
   us.def(
       "apply_int_property_value",
@@ -151,16 +160,53 @@ void init_uniset(py::module &m) {
           },
           py::arg("pattern"));
   us.def(
-      "apply_property_alias",
-      [](UnicodeSet &self, const UnicodeString &prop, const UnicodeString &value) -> UnicodeSet & {
-        UErrorCode error_code = U_ZERO_ERROR;
-        auto &result = self.applyPropertyAlias(prop, value, error_code);
-        if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
-        }
-        return result;
-      },
-      py::arg("prop"), py::arg("value"));
+        "apply_property_alias",
+        [](UnicodeSet &self, const UnicodeString &prop, const UnicodeString &value) -> UnicodeSet & {
+          UErrorCode error_code = U_ZERO_ERROR;
+          auto &result = self.applyPropertyAlias(prop, value, error_code);
+          if (U_FAILURE(error_code)) {
+            throw ICUException(error_code);
+          }
+          return result;
+        },
+        py::arg("prop"), py::arg("value"))
+      .def(
+          // const char16_t *prop -> const UnicodeString &prop
+          "apply_property_alias",
+          [](UnicodeSet &self, const char16_t *prop, const UnicodeString &value) -> UnicodeSet & {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto &result = self.applyPropertyAlias(prop, value, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("prop"), py::arg("value"))
+      .def(
+          // const char16_t *value -> const UnicodeString &value
+          "apply_property_alias",
+          [](UnicodeSet &self, const UnicodeString &prop, const char16_t *value) -> UnicodeSet & {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto &result = self.applyPropertyAlias(prop, value, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("prop"), py::arg("value"))
+      .def(
+          // const char16_t *prop -> const UnicodeString &prop
+          // const char16_t *value -> const UnicodeString &value
+          "apply_property_alias",
+          [](UnicodeSet &self, const char16_t *prop, const char16_t *value) -> UnicodeSet & {
+            UErrorCode error_code = U_ZERO_ERROR;
+            auto &result = self.applyPropertyAlias(prop, value, error_code);
+            if (U_FAILURE(error_code)) {
+              throw ICUException(error_code);
+            }
+            return result;
+          },
+          py::arg("prop"), py::arg("value"));
   us.def("char_at", &UnicodeSet::charAt, py::arg("index"));
   us.def("clear", &UnicodeSet::clear);
   us.def("clone", &UnicodeSet::clone);
@@ -174,24 +220,41 @@ void init_uniset(py::module &m) {
   us.def("complement_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::complementAll), py::arg("c"))
       .def("complement_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::complementAll), py::arg("s"));
   us.def("contains", py::overload_cast<const UnicodeString &>(&UnicodeSet::contains, py::const_), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "contains", [](const UnicodeSet &self, const char16_t *s) { return self.contains(s); }, py::arg("s"))
       .def("contains", py::overload_cast<UChar32>(&UnicodeSet::contains, py::const_), py::arg("c"))
       .def("contains", py::overload_cast<UChar32, UChar32>(&UnicodeSet::contains, py::const_), py::arg("start"),
            py::arg("end"));
   us.def("contains_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::containsAll, py::const_), py::arg("c"))
-      .def("contains_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::containsAll, py::const_),
-           py::arg("s"));
+      .def("contains_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::containsAll, py::const_), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "contains_all", [](const UnicodeSet &self, const char16_t *s) { return self.containsAll(s); }, py::arg("s"));
   us.def("contains_none", py::overload_cast<const UnicodeSet &>(&UnicodeSet::containsNone, py::const_), py::arg("c"))
       .def("contains_none", py::overload_cast<const UnicodeString &>(&UnicodeSet::containsNone, py::const_),
            py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "contains_none", [](const UnicodeSet &self, const char16_t *s) { return self.containsNone(s); }, py::arg("s"))
       .def("contains_none", py::overload_cast<UChar32, UChar32>(&UnicodeSet::containsNone, py::const_),
            py::arg("start"), py::arg("end"));
   us.def("contains_some", py::overload_cast<const UnicodeSet &>(&UnicodeSet::containsSome, py::const_), py::arg("c"))
       .def("contains_some", py::overload_cast<const UnicodeString &>(&UnicodeSet::containsSome, py::const_),
            py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "contains_some", [](const UnicodeSet &self, const char16_t *s) { return self.containsSome(s); }, py::arg("s"))
       .def("contains_some", py::overload_cast<UChar32, UChar32>(&UnicodeSet::containsSome, py::const_),
            py::arg("start"), py::arg("end"));
-  us.def_static("create_from", &UnicodeSet::createFrom, py::arg("s"));
-  us.def_static("create_from_all", &UnicodeSet::createFromAll, py::arg("s"));
+  us.def_static("create_from", &UnicodeSet::createFrom, py::arg("s"))
+      .def_static(
+          // const char16_t *s -> const UnicodeString &s
+          "create_from", [](const char16_t *s) { return UnicodeSet::createFrom(s); }, py::arg("s"));
+  us.def_static("create_from_all", &UnicodeSet::createFromAll, py::arg("s"))
+      .def_static(
+          // const char16_t *s -> const UnicodeString &s
+          "create_from_all", [](const char16_t *s) { return UnicodeSet::createFromAll(s); }, py::arg("s"));
   us.def("freeze", &UnicodeSet::freeze);
   us.def_static(
         "from_uset", [](_ConstUSetPtr &uset) { return UnicodeSet::fromUSet(uset); }, py::return_value_policy::reference,
@@ -215,16 +278,32 @@ void init_uniset(py::module &m) {
       },
       py::arg("text"), py::arg("offset"), py::arg("limit"), py::arg("incremental"));
   us.def("remove", py::overload_cast<const UnicodeString &>(&UnicodeSet::remove), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "remove", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.remove(s); })
       .def("remove", py::overload_cast<UChar32>(&UnicodeSet::remove), py::arg("c"))
       .def("remove", py::overload_cast<UChar32, UChar32>(&UnicodeSet::remove), py::arg("start"), py::arg("end"));
   us.def("remove_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::removeAll), py::arg("c"))
-      .def("remove_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::removeAll), py::arg("s"));
+      .def("remove_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::removeAll), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "remove_all", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.removeAll(s); },
+          py::arg("s"));
   us.def("remove_all_strings", &UnicodeSet::removeAllStrings);
-  us.def_static("resembles_pattern", &UnicodeSet::resemblesPattern, py::arg("pattern"), py::arg("pos"));
+  us.def_static("resembles_pattern", &UnicodeSet::resemblesPattern, py::arg("pattern"), py::arg("pos"))
+      .def_static(
+          // const char16_t *pattern -> const UnicodeString &pattern
+          "resembles_pattern",
+          [](const char16_t *pattern, int32_t pos) { return UnicodeSet::resemblesPattern(pattern, pos); },
+          py::arg("pattern"), py::arg("pos"));
   us.def("retain", py::overload_cast<UChar32>(&UnicodeSet::retain), py::arg("c"))
       .def("retain", py::overload_cast<UChar32, UChar32>(&UnicodeSet::retain), py::arg("start"), py::arg("end"));
   us.def("retain_all", py::overload_cast<const UnicodeSet &>(&UnicodeSet::retainAll), py::arg("c"))
-      .def("retain_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::retainAll), py::arg("s"));
+      .def("retain_all", py::overload_cast<const UnicodeString &>(&UnicodeSet::retainAll), py::arg("s"))
+      .def(
+          // const char16_t *s -> const UnicodeString &s
+          "retain_all", [](UnicodeSet &self, const char16_t *s) -> UnicodeSet & { return self.retainAll(s); },
+          py::arg("s"));
   us.def("serialize", [](const UnicodeSet &self) {
     UErrorCode error_code = U_ZERO_ERROR;
     const auto length = self.serialize(NULL, 0, error_code);
